#!/bin/bash
CERTFILE=$1
CHAINFILE=$2
ENVOY_CONFIG=/envoy/config/envoy-config.yaml
ENVOY_CONFIG_OCSP=/envoy/config/envoy-config-ocsp.yaml
export ENVOY_CONFIG;
filesPresent=0
OCSP_RESPONSE=/data/certs/good_ocsp_resp.der
OCSP_CHECK_LOGFILE=/data/logs/ocsp.log

echo ================================================= >> $OCSP_CHECK_LOGFILE
echo `date "+%Y-%m-%d %H:%M:%S"` >> $OCSP_CHECK_LOGFILE

function check() {
  local certOk=0
  local chainOk=0

  if [ -f "$CERTFILE" ]; then
    certOk=1
  fi

  if [ -f "$CHAINFILE" ]; then
    chainOk=1
  fi;

  filesPresent=$(( $certOk && $chainOk ))
}

check

if [[ $filesPresent == 1 ]]; then
  echo "Certificate chain found, performing OCSP stapling" >> $OCSP_CHECK_LOGFILE
  openssl x509 -noout -ocsp_uri -in $CERTFILE > ocsp_endpoint.txt
  ocsp_responder_url=$(<ocsp_endpoint.txt)
  echo "OCSP responder URL=$ocsp_responder_url" >> $OCSP_CHECK_LOGFILE
  rm ocsp_endpoint.txt
  if [ ! -z "$ocsp_responder_url" ]; then
    export ENVOY_CONFIG=$ENVOY_CONFIG_OCSP
    openssl ocsp -issuer $CHAINFILE -cert $CERTFILE -verify_other $CHAINFILE -CAfile $CHAINFILE -no_nonce -url $ocsp_responder_url -respout $OCSP_RESPONSE
    echo "OCSP response captured" >> $OCSP_CHECK_LOGFILE
  fi
else
  echo "Certificate chain does not exist, hence OCSP stapling is not applicable" >> $OCSP_CHECK_LOGFILE
fi
echo ================================================= >> $OCSP_CHECK_LOGFILE