#!/bin/bash
CERTFILE=$1
CHAINFILE=$2
OCSP_RESPONSE=/data/certs/good_ocsp_resp.der
filesPresent=0
OCSP_CHECK_LOGFILE=/data/logs/ocsp.log

echo ================================================= >> $OCSP_CHECK_LOGFILE
echo `date "+%Y-%m-%d %H:%M:%S"` >> $OCSP_CHECK_LOGFILE

function check() {
  local certOk=0
  local chainOk=0

  if [ -f "$CERTFILE" ]; then
    certOk=1
  fi

  if [ -f "$CHAINFILE" ]; then
    chainOk=1
  fi;

  filesPresent=$(( $certOk && $chainOk ))
}

check


if [[ $filesPresent == 1 ]]; then
  echo "Certificate chain found, performing OCSP stapling" >> $OCSP_CHECK_LOGFILE
  openssl x509 -noout -ocsp_uri -in $CERTFILE > ocsp_endpoint.txt
  ocsp_responder_url=$(<ocsp_endpoint.txt)
  echo "OCSP responder URL=$ocsp_responder_url" >> $OCSP_CHECK_LOGFILE
  rm ocsp_endpoint.txt
  if [ ! -z "$ocsp_responder_url" ]; then
    openssl ocsp -issuer $CHAINFILE -cert $CERTFILE -verify_other $CHAINFILE -CAfile $CHAINFILE -no_nonce -url $ocsp_responder_url -respout $OCSP_RESPONSE
    ENVOY_PID=`ps -ef | grep envoy | grep -v grep | awk '{print $2}'`
    kill -s SIGTERM $ENVOY_PID
  fi
else
  echo "Certificate or Chain File does not exist" >> $OCSP_CHECK_LOGFILE
  echo "Syntax: ocsp_job.sh <certificate_pem_file> <chain_pem_file>" >> $OCSP_CHECK_LOGFILE
fi
echo ================================================= >> $OCSP_CHECK_LOGFILE